module HROOT.Graf.TGaxis
       (TGaxis(..), ITGaxis, upcastTGaxis, downcastTGaxis, newTGaxis)
       where
import HROOT.Graf.TGaxis.RawType
import HROOT.Graf.TGaxis.Interface
import HROOT.Graf.TGaxis.Implementation
